==> owncloud-8.0.11.tar.bz2: owncloud/apps/activity/l10n/sr@latin.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivnosti",
    "Your settings have been updated." : "Vaša podešavanja su osvežena.",
    "A file or folder has been <strong>shared</strong>" : "Fijl ili direktorijum je <strong>podeljen</strong>",
    "A new file or folder has been <strong>created</strong>" : "Novi fajl ili direktorijum je <strong>kreiran</strong>",
    "A file or folder has been <strong>changed</strong>" : "Faj ili direktorijum je <strong>promenjen</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fajl ili direktorijum je <strong>uklonjen</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fajl ili direktorijum je <strong>povraćen</strong>",
    "You created %1$s" : "Kreirali ste %1$s",
    "%2$s created %1$s" : "%2$s je kreirao %1$s",
    "%1$s was created in a public folder" : "%1$s je kreiran u javnom direktorijumu",
    "You changed %1$s" : "Izmenili ste %1$s",
    "%2$s changed %1$s" : "%2$s je izmenio %1$s",
    "You deleted %1$s" : "Obrisali ste %1$s",
    "%2$s deleted %1$s" : "%2$s je obrisao %1$s",
    "You restored %1$s" : "Povratili ste %1$s",
    "%2$s restored %1$s" : "%2$s je povratio %1$s",
    "You shared %1$s with %2$s" : "Delili ste %1$s sa %2$s",
    "You shared %1$s with group %2$s" : "Delili ste %1$s sa grupom %2$s",
    "%2$s shared %1$s with you" : "%2$s je delio %1$s sa Vama",
    "You shared %1$s via link" : "Delili ste %1$s pomoću prečice",
    "Activity notification" : "Obaveštenje o aktivnosti",
    "All Activities" : "Sve aktivnosti",
    "Activities by you" : "Vaše aktivnosti",
    "Activities by others" : "Tuđe aktivnosti",
    "Shares" : "Deljenja",
    "Files" : "Fajlovi",
    "in %s" : "u %s",
    "%s and %s" : "%s i %s",
    ", " : ", ",
    "%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>::%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>" : ["%s i <strong class=\"tooltip\" title=\"%s\">%n drugih</strong>","%s i <strong class=\"tooltip\" title=\"%s\">%n drugih</strong>","%s i <strong class=\"tooltip\" title=\"%s\">%n drugih</strong>"],
    "%s and %n more::%s and %n more" : ["%s i %n drugih","%s i %n drugih","%s i %n drugih"],
    "Hello %s," : "Pozdrav %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Primate ovaj email jer su se u poslednjih sat vremena desile sledeće stvari na %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Primate ovaj email jer su se u poslednjem danu sledeće stvari desile na %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Primate ovaj email jer su se u poslednjoj nedelji sledeće stvari desile na %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "You will see a list of events here when you start to use your %s." : "Ovdje će vam se prikazati lista aktivnosti kada počnete da koristite %s.",
    "No more events to load" : "Nema više događaja za učitavanje",
    "Enable RSS feed" : "Omogući RSS ",
    "Notifications" : "Obaveštenja",
    "Mail" : "Pošta",
    "Stream" : "Tok",
    "List your own actions in the stream" : "Izlistajte Vaše postupke u toku",
    "Notify about your own actions via email" : "Obavesti o Vašim postupcima putem Email-a",
    "You need to set up your email address before you can receive notification emails." : "Morate da podesite svoju email adresu da biste mogli da primate email obaveštenja.",
    "Send emails:" : "Pošalji email-ove:",
    "Hourly" : "časovno",
    "Daily" : "dnevno",
    "Weekly" : "nedeljno",
    "Activity feed" : "Lista aktivnosti",
    "Personal activity feed for %s" : "Lična lista aktivnosti za %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-8.2.11.tar.bz2: owncloud/apps/activity/l10n/sr@latin.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivnosti",
    "Personal activity feed for %s" : "Lična lista aktivnosti za %s",
    "Your settings have been updated." : "Vaša podešavanja su osvežena.",
    "Mail" : "Pošta",
    "Stream" : "Tok",
    "Activity notification" : "Obaveštenje o aktivnosti",
    "All Activities" : "Sve aktivnosti",
    "Activities by you" : "Vaše aktivnosti",
    "Activities by others" : "Tuđe aktivnosti",
    "in %s" : "u %s",
    "%s and %s" : "%s i %s",
    ", " : ", ",
    "_%s and %n more_::_%s and %n more_" : ["%s i %n drugih","%s i %n drugih","%s i %n drugih"],
    "Hello %s," : "Pozdrav %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Primate ovaj email jer su se u poslednjih sat vremena desile sledeće stvari na %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Primate ovaj email jer su se u poslednjem danu sledeće stvari desile na %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Primate ovaj email jer su se u poslednjoj nedelji sledeće stvari desile na %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "Notifications" : "Obaveštenja",
    "List your own actions in the stream" : "Izlistajte Vaše postupke u toku",
    "Notify about your own actions via email" : "Obavesti o Vašim postupcima putem Email-a",
    "You need to set up your email address before you can receive notification emails." : "Morate da podesite svoju email adresu da biste mogli da primate email obaveštenja.",
    "Send emails:" : "Pošalji email-ove:",
    "Hourly" : "časovno",
    "Daily" : "dnevno",
    "Weekly" : "nedeljno",
    "Activity feed" : "Lista aktivnosti",
    "Enable RSS feed" : "Omogući RSS ",
    "No more events to load" : "Nema više događaja za učitavanje",
    "Files" : "Fajlovi"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
